summaryrefslogtreecommitdiff
path: root/src/reel_sound_asset.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/reel_sound_asset.h')
-rw-r--r--src/reel_sound_asset.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/reel_sound_asset.h b/src/reel_sound_asset.h
index 92667429..d7eee59d 100644
--- a/src/reel_sound_asset.h
+++ b/src/reel_sound_asset.h
@@ -22,7 +22,7 @@
*/
#include "reel_mxf_asset.h"
-#include "sound_mxf.h"
+#include "sound_asset.h"
#include <boost/shared_ptr.hpp>
#include <string>
@@ -34,19 +34,19 @@ namespace dcp {
class ReelSoundAsset : public ReelMXFAsset
{
public:
- ReelSoundAsset (boost::shared_ptr<dcp::SoundMXF> content, int64_t entry_point);
+ ReelSoundAsset (boost::shared_ptr<dcp::SoundAsset> content, int64_t entry_point);
ReelSoundAsset (boost::shared_ptr<const cxml::Node>);
void write_to_cpl (xmlpp::Node* node, Standard standard) const;
- /** @return the SoundMXF that this object refers to */
- boost::shared_ptr<SoundMXF> mxf () {
- return boost::dynamic_pointer_cast<SoundMXF> (_asset.object ());
+ /** @return the SoundAsset that this object refers to */
+ boost::shared_ptr<SoundAsset> asset () {
+ return boost::dynamic_pointer_cast<SoundAsset> (_asset_ref.object ());
}
- /** @return the SoundMXF that this object refers to */
- boost::shared_ptr<const SoundMXF> mxf () const {
- return boost::dynamic_pointer_cast<const SoundMXF> (_asset.object ());
+ /** @return the SoundAsset that this object refers to */
+ boost::shared_ptr<const SoundAsset> asset () const {
+ return boost::dynamic_pointer_cast<const SoundAsset> (_asset_ref.object ());
}
private: